@@ -53,6 +53,7 @@ LogEvent <- R6::R6Class(
       timestamp = Sys.time(),
       caller = NA,
       msg = NA,
+      rawMsg = msg,
       ...
     ){
       assert(inherits(logger, "Logger"), "Logger must be a <Logger> object, not a ", class_fmt(logger))
@@ -64,6 +65,7 @@ LogEvent <- R6::R6Class(
       assign("timestamp", timestamp, self)
       assign("caller", caller, self)
       assign("msg", msg, self)
+      assign("rawMsg", rawMsg, self)
 
       # custom values
       if (!missing(...)){
@@ -94,7 +96,11 @@ LogEvent <- R6::R6Class(
 
     #' @field .logger [Logger]. A reference to the Logger that created the
     #' event (equivalent to `get_logger(event$logger)`).
-    .logger = NULL
+    .logger = NULL,
+
+    #' @field rawMsg `character`. The raw log message without string
+    #'   interpolation.
+    rawMsg = NULL
   ),
 
   active = list(
@@ -102,11 +108,10 @@ LogEvent <- R6::R6Class(
     #' @field values `list`. All values stored in the `LogEvent`, including
     #' all *custom fields*, but not including `event$.logger`.
     values = function(){
-      fixed_vals   <- c("level", "timestamp", "logger", "caller", "msg")
+      fixed_vals   <- c("level", "timestamp", "logger", "caller", "msg", "rawMsg")
       custom_vals <- setdiff(
         names(get(".__enclos_env__", self)[["self"]]),
-        c(".__enclos_env__", "level_name", "initialize", "clone", "values",
-          ".logger")
+        c(".__enclos_env__", "level_name", "initialize", "clone", "values", ".logger")
       )
       valnames <- union(fixed_vals, custom_vals) # to enforce order of fixed_vals
       mget(valnames, envir = self)
@@ -313,6 +318,8 @@ as_tibble.LogEvent <- function(
 #' @inheritParams standardize_threshold
 #' @param pad_levels `right`, `left` or `NULL`. Whether or not to pad the log
 #'   level names to the same width on the left or right side, or not at all.
+#' @param excluded_fields a `character` vector of fields to exclude from `%j` and
+#'   `%f`
 #' @param ... ignored
 #'
 #' @section Format Tokens:
@@ -329,6 +336,7 @@ as_tibble.LogEvent <- function(
 #'       multiple threads.}
 #'   \item{`%c`}{the calling function}
 #'   \item{`%m`}{the log message}
+#'   \item{`%r`}{the raw log message (without string interpolation)}
 #'   \item{`%f`}{all custom fields of `x` in a pseudo-JSON like format that is
 #'     optimized for human readability and console output}
 #'   \item{`%j`}{all custom fields of `x` in proper JSON. This requires that you
@@ -370,6 +378,7 @@ print.LogEvent <- function(
   colors = getOption("lgr.colors"),
   log_levels = getOption("lgr.log_levels"),
   pad_levels = "right",
+  excluded_fields = NULL,
   ...
 ){
   cat(format(
@@ -378,7 +387,8 @@ print.LogEvent <- function(
     timestamp_fmt = timestamp_fmt,
     colors = colors,
     log_levels = log_levels,
-    pad_levels = pad_levels
+    pad_levels = pad_levels,
+    excluded_fields = excluded_fields
   ), sep = "\n")
   invisible(x)
 }
@@ -395,6 +405,7 @@ format.LogEvent <- function(
   colors = NULL,
   log_levels = getOption("lgr.log_levels"),
   pad_levels = "right",
+  excluded_fields = NULL,
   ...
 ){
   stopifnot(
@@ -427,7 +438,7 @@ format.LogEvent <- function(
     fmt,
     valid_tokens = paste0(
       "%",
-      c("t", "p", "c", "m", "l", "L", "n", "f", "j", "k", "K", "g"))
+      c("t", "p", "c", "m", "r", "l", "L", "n", "f", "j", "k", "K", "g"))
   )
 
   # format
@@ -444,11 +455,12 @@ format.LogEvent <- function(
       "%K" = colorize_levels(lvls, colors, transform = function(.) toupper(strtrim(., 1))),
       "%t" = format(get("timestamp", envir = x), format = timestamp_fmt),
       "%m" = get("msg", envir = x),
+      "%r" = get("rawMsg", envir = x),
       "%c" = get("caller", envir = x),
       "%g" = get("logger", envir = x),
       "%p" = Sys.getpid(),
-      "%f" = format_custom_fields(get_custom_fields(x), color = length(colors)),
-      "%j" = format_custom_fields_json(get_custom_fields(x)),
+      "%f" = format_custom_fields(get_custom_fields(x, excluded_fields), color = length(colors)),
+      "%j" = format_custom_fields_json(get_custom_fields(x, excluded_fields)),
       tokens[[i]]
     )
   }
@@ -508,8 +520,8 @@ do_box_if <- function(x, predicate, except, boxer = list){
 
 
 
-get_custom_fields <- function(x){
-  x$values[!names(x$values) %in% DEFAULT_FIELDS]
+get_custom_fields <- function(x, excluded_fields = NULL){
+  x$values[!names(x$values) %in% c(DEFAULT_FIELDS, excluded_fields)]
 }
 
 
@@ -591,4 +603,4 @@ tokenize_format <- function(
 
 # globals --------------------------------------------------------
 
-DEFAULT_FIELDS <- c("level", "timestamp", "logger", "caller", "msg")
+DEFAULT_FIELDS <- c("level", "timestamp", "logger", "caller", "msg", "rawMsg")
