@@ -105,7 +105,7 @@
 NULL
 
 
-
+# Logger ------------------------------------------------------------------
 
 #' @export
 Logger <- R6::R6Class(
@@ -148,7 +148,8 @@ Logger <- R6::R6Class(
       threshold = NULL,
       filters = list(),
       exception_handler = default_exception_handler,
-      propagate = TRUE
+      propagate = TRUE,
+      replace_empty = "<NULL>"
     ){
       # fields
       # threshold must be set *after* the logging functions have been initalized
@@ -167,6 +168,7 @@ Logger <- R6::R6Class(
       self$set_propagate(propagate)
       self$set_filters(filters)
       self$set_exception_handler(exception_handler)
+      self$set_replace_empty(replace_empty)
 
       invisible(self)
     },
@@ -212,8 +214,8 @@ Logger <- R6::R6Class(
 
         # Check if LogEvent should be created
         if (
-          identical(level[[1]] > get("threshold", envir = self), TRUE) ||
-          identical(getOption("lgr.logging_suspended"), TRUE)
+          isTRUE(level[[1]] > get("threshold", envir = self)) ||
+          isTRUE(getOption("lgr.logging_suspended"))
         ){
           return(invisible(msg))
         }
@@ -226,6 +228,7 @@ Logger <- R6::R6Class(
         }
 
         force(caller)
+        rawMsg <- msg
 
         if (missing(...)){
           vals <- list(
@@ -233,24 +236,31 @@ Logger <- R6::R6Class(
             level = level,
             timestamp = timestamp,
             caller = caller,
-            msg = msg
+            msg = msg,
+            rawMsg = rawMsg
           )
         } else {
           dots <- list(...)
 
           if (is.null(names(dots))){
-            msg  <- sprintf(msg, ...)
+            dots <- replace_empty(dots, get("replace_empty", self))
+
+            msg  <- do.call(sprintf, args = c(list(msg), dots))
             vals <- list(
               logger = self,
               level = level,
               timestamp = timestamp,
               caller = caller,
-              msg = msg
+              msg = msg,
+              rawMsg = rawMsg
             )
           } else {
             not_named <- vapply(names(dots), is_blank, TRUE, USE.NAMES = FALSE)
+            unnamed_dots <- dots[not_named]
+            unnamed_dots <- replace_empty(unnamed_dots, get("replace_empty", self))
+
             if (any(not_named)){
-              msg <- do.call(sprintf, c(list(msg), dots[not_named]))
+              msg <- do.call(sprintf, c(list(msg), unnamed_dots))
             }
 
             vals <- c(
@@ -259,7 +269,8 @@ Logger <- R6::R6Class(
                 level = level,
                 timestamp = timestamp,
                 caller = caller,
-                msg = msg
+                msg = msg,
+                rawMsg = rawMsg
               ),
               dots[!not_named]
             )
@@ -305,7 +316,7 @@ Logger <- R6::R6Class(
     #' @description Log an Event fatal priority
     #' @param msg,...,caller see `$log()`
     fatal = function(msg, ..., caller = get_caller(-8L)){
-      if (identical(get("threshold", envir = self) < 100L, TRUE))
+      if (isTRUE(get("threshold", envir = self) < 100L))
         return(invisible())
 
       get("log", envir = self)(
@@ -321,7 +332,7 @@ Logger <- R6::R6Class(
     #' @description Log an Event error priority
     #' @param msg,...,caller see `$log()`
     error = function(msg, ..., caller = get_caller(-8L)){
-      if (identical(get("threshold", envir = self) < 200L, TRUE))
+      if (isTRUE(get("threshold", envir = self) < 200L))
         return(invisible())
 
       get("log", envir = self)(
@@ -337,7 +348,7 @@ Logger <- R6::R6Class(
     #' @description Log an Event warn priority
     #' @param msg,...,caller see `$log()`
     warn = function(msg, ..., caller = get_caller(-8L)){
-      if (identical(get("threshold", envir = self) < 300L, TRUE))
+      if (isTRUE(get("threshold", envir = self) < 300L))
         return(invisible())
 
       get("log", envir = self)(
@@ -353,7 +364,7 @@ Logger <- R6::R6Class(
     #' @description Log an Event info priority
     #' @param msg,...,caller see `$log()`
     info = function(msg, ..., caller = get_caller(-8L)){
-      if (identical(get("threshold", envir = self) < 400L, TRUE))
+      if (isTRUE(get("threshold", envir = self) < 400L))
         return(invisible())
 
       get("log", envir = self)(
@@ -369,7 +380,7 @@ Logger <- R6::R6Class(
     #' @description Log an Event debug priority
     #' @param msg,...,caller see `$log()`
     debug = function(msg, ..., caller = get_caller(-8L)){
-      if (identical(get("threshold", envir = self) < 500L, TRUE))
+      if (isTRUE(get("threshold", envir = self) < 500L))
         return(invisible())
 
       get("log", envir = self)(
@@ -385,7 +396,7 @@ Logger <- R6::R6Class(
     #' @description Log an Event trace priority
     #' @param msg,...,caller see `$log()`
     trace = function(msg, ..., caller = get_caller(-8L)){
-      if (identical(get("threshold", envir = self) < 600L, TRUE))
+      if (isTRUE(get("threshold", envir = self) < 600L))
         return(invisible())
 
       get("log", envir = self)(
@@ -555,6 +566,8 @@ Logger <- R6::R6Class(
     },
 
 
+    # .. setters --------------------------------------------------------------
+
     #' @description Set the exception handler of a logger
     #'
     #' @param fun a `function` with the single argument `e` (an error [condition])
@@ -607,6 +620,17 @@ Logger <- R6::R6Class(
       invisible(self)
     },
 
+    #' @description Set the replacement for empty values (`NULL` or empty
+    #'   vectors)
+    #'
+    #' @param x should be a `character` vector, but other types of values are
+    #'   supported. use wisely.
+    set_replace_empty = function(x){
+      private[[".replace_empty"]] <- x
+
+      invisible(self)
+    },
+
 
     #' @description Spawn a child Logger.
     #' This is very similar to using [get_logger()], but
@@ -621,7 +645,7 @@ Logger <- R6::R6Class(
   ),
 
 
-  # active bindings ---------------------------------------------------------
+  # .. active bindings ---------------------------------------------------------
   active = list(
 
     #' @field name A `character` scalar. The unique name of each logger,
@@ -644,8 +668,8 @@ Logger <- R6::R6Class(
     },
 
 
-    #' @field propagate A `TRUE` or `FALSE`. The unique name of each logger,
-    #' which also includes the names of its ancestors (separated by `/`).
+    #' @field propagate A `TRUE` or `FALSE`. Should a Logger propagate events
+    #' to the Appenders of its ancestors?
     propagate = function(){
       get(".propagate", envir = private)
     },
@@ -712,6 +736,9 @@ Logger <- R6::R6Class(
       }
     },
 
+    replace_empty = function() {
+      get(".replace_empty", envir = private)
+    },
 
     #' @field exception_handler a `function`. See `$set_exception_handler` and
     #'   `$handle_exception`
@@ -721,7 +748,7 @@ Logger <- R6::R6Class(
   ),
 
 
-  # private -----------------------------------------------------------------
+  # .. private -----------------------------------------------------------------
   private = list(
     set_name = function(x){
       assert(is_scalar_character(x))
@@ -743,13 +770,13 @@ Logger <- R6::R6Class(
       invisible()
     },
 
-    # +- fields ---------------------------------------------------------------
     .propagate = NULL,
     .exception_handler = NULL,
     .name = NULL,
     .appenders = NULL,
     .threshold = NULL,
-    .last_event = NULL
+    .last_event = NULL,
+    .replace_empty = NULL
   )
 )
 
@@ -780,8 +807,42 @@ LoggerGlue <- R6::R6Class(
 
   public = list(
 
+    initialize = function(
+      name = "(unnamed logger)",
+      appenders = list(),
+      threshold = NULL,
+      filters = list(),
+      exception_handler = default_exception_handler,
+      propagate = TRUE,
+      replace_empty = "<NULL>",
+      transformer = NULL
+      ){
+        # fields
+        # threshold must be set *after* the logging functions have been initalized
+        if (identical(name, "(unnamed logger)")){
+          warning(
+            "When creating a new Logger, you should assign it a unique `name`. ",
+            "Please see ?Logger for more infos.", call. = FALSE
+          )
+        }
+
+        private$set_name(name)
+        private$.last_event <- LogEvent$new(self)
+
+        self$set_threshold(threshold)
+        self$set_appenders(appenders)
+        self$set_propagate(propagate)
+        self$set_filters(filters)
+        self$set_exception_handler(exception_handler)
+        self$set_replace_empty(replace_empty)
+        self$set_transformer(transformer)
+
+        invisible(self)
+      },
+
+    # .. methods --------------------------------------------------------------
     fatal = function(..., caller = get_caller(-8L), .envir = parent.frame()){
-      if (identical(get("threshold", envir = self) < 100L, TRUE))
+      if (isTRUE(get("threshold", envir = self) < 100L))
         return(invisible())
 
       force(.envir)
@@ -795,7 +856,7 @@ LoggerGlue <- R6::R6Class(
     },
 
     error = function(..., caller = get_caller(-8L), .envir = parent.frame()){
-      if (identical(get("threshold", envir = self) < 200L, TRUE))
+      if (isTRUE(get("threshold", envir = self) < 200L))
         return(invisible())
 
       get("log", envir = self)(
@@ -808,7 +869,7 @@ LoggerGlue <- R6::R6Class(
     },
 
     warn = function(..., caller = get_caller(-8L), .envir = parent.frame()){
-      if (identical(get("threshold", envir = self) < 300L, TRUE))
+      if (isTRUE(get("threshold", envir = self) < 300L))
         return(invisible())
 
       get("log", envir = self)(
@@ -821,7 +882,7 @@ LoggerGlue <- R6::R6Class(
     },
 
     info = function(..., caller = get_caller(-8L), .envir = parent.frame()){
-      if (identical(get("threshold", envir = self) < 400L, TRUE))
+      if (isTRUE(get("threshold", envir = self) < 400L))
         return(invisible())
 
       get("log", envir = self)(
@@ -834,7 +895,7 @@ LoggerGlue <- R6::R6Class(
     },
 
     debug = function(..., caller = get_caller(-8L), .envir = parent.frame()){
-      if (identical(get("threshold", envir = self) < 500L, TRUE))
+      if (isTRUE(get("threshold", envir = self) < 500L))
         return(invisible())
 
       force(.envir)
@@ -848,7 +909,7 @@ LoggerGlue <- R6::R6Class(
     },
 
     trace = function(..., caller = get_caller(-8L), .envir = parent.frame()){
-      if (identical(get("threshold", envir = self) < 600L, TRUE))
+      if (isTRUE(get("threshold", envir = self) < 600L))
         return(invisible())
 
       force(.envir)
@@ -882,6 +943,11 @@ LoggerGlue <- R6::R6Class(
           "Can only utilize vectorized logging if log level is the same for all entries"
         )
 
+        assert(
+          !missing(...),
+          "No log message or structured logging fields supplied"
+        )
+
         dots <- list(...)
 
         if ("msg" %in% names(dots)){
@@ -909,34 +975,44 @@ LoggerGlue <- R6::R6Class(
           }
         })
 
-        msg <- do.call(glue::glue, args = c(dots_msg, list(.envir = .envir)))
+        dots_msg <- replace_empty(dots_msg, get("replace_empty", self))
+        rawMsg <- dots[[1]]
+
+        glue_args <- list(.envir = .envir)
+
+        transformer <- get("transformer", self)
+
+        if (!is.null(transformer)){
+          glue_args[[".transformer"]] <- transformer
+        }
+
+        msg <- do.call(glue::glue, args = c(dots_msg, glue_args))
 
         # Check if LogEvent should be created
         if (
-          identical(level[[1]] > get("threshold", envir = self), TRUE) ||
-          identical(getOption("lgr.logging_suspended"), TRUE)
+          isTRUE(level[[1]] > get("threshold", envir = self)) ||
+          isTRUE(getOption("lgr.logging_suspended"))
         ){
           return(invisible(msg))
         }
 
         force(caller)
 
-        if (missing(...)){
-          stop("No log message or structured logging fields supplied")
-        } else {
-          custom_fields <- !(grepl("^\\.", names(dots)) | is_blank(names(dots)))
+        # Create list that contains all values equired for the log event
+        custom_fields <- !(grepl("^\\.", names(dots)) | is_blank(names(dots)))
+
+        vals <- c(
+          list(
+            logger = self,
+            level = level,
+            timestamp = timestamp,
+            caller = caller,
+            msg = msg,
+            rawMsg = rawMsg
+          ),
+          dots[custom_fields]
+        )
 
-          vals <- c(
-            list(
-              logger = self,
-              level = level,
-              timestamp = timestamp,
-              caller = caller,
-              msg = msg
-            ),
-            dots[custom_fields]
-          )
-        }
 
         # This code looks really weird, but it really is just replacing all
         # instances of [[ with get() for minimal overhead. We want event
@@ -983,7 +1059,31 @@ LoggerGlue <- R6::R6Class(
 
     spawn = function(name){
       get_logger_glue(c(private[[".name"]], name))
+    },
+
+    # .. setters -----------------------------------------------------------------
+
+    #' @description Set the transformer for glue string interpolation
+    #'
+    #' @param x single [function] taking two arguments. See [glue::glue()].
+    set_transformer = function(x){
+      private[[".transformer"]] <- x
+
+      invisible(self)
     }
+  ),
+
+  # .. active bindings ---------------------------------------------------
+  active = list(
+    transformer = function() {
+      get(".transformer", envir = private)
+    }
+  ),
+
+
+  # . private ------------------------------------
+  private = list(
+    .transformer = NULL
   )
 )
 
