@@ -11,21 +11,14 @@ teardown({
   unlink(td, recursive = TRUE)
 })
 
-
-assert_supported_rotor_version <- function(){  # TODO: change to throwing an error once rotor 0.3.0 is on CRAN
-  if (packageVersion("rotor") < "0.3.0")
-    skip("rotor < 0.3.0 is no longer supported")
-}
-
-
-
 # AppenderFileRotating -----------------------------------------------------
 
 test_that("AppenderFileRotating: works as expected", {
-  if (!is_zipcmd_available())
-    skip("Test requires a workings system zip command")
+  skip_if_not_installed("rotor", "0.3.0")
 
-  assert_supported_rotor_version()
+  if (!is_zipcmd_available()){
+    skip("Test requires a workings system zip command")
+  }
 
   tf <- file.path(td, "test.log")
   app <- AppenderFileRotating$new(file = tf, size = "1tb")
@@ -77,10 +70,11 @@ test_that("AppenderFileRotating: works as expected", {
 
 
 test_that("AppenderFileRotating: works with different backup_dir", {
-  if (!is_zipcmd_available())
+  if (!is_zipcmd_available()) {
     skip("Test requires a workings system zip command")
+  }
 
-  assert_supported_rotor_version()
+  skip_if_not_installed("rotor", "0.3.0")
 
   tf     <- file.path(td, "test.log")
   bu_dir <- file.path(td, "backups")
@@ -136,7 +130,7 @@ test_that("AppenderFileRotating: works with different backup_dir", {
 
 test_that("AppenderFileRotating: `size` argument works as expected", {
 
-  assert_supported_rotor_version()
+  skip_if_not_installed("rotor", "0.3.0")
 
   #setup
     tf <- file.path(td, "test.log")
@@ -167,7 +161,7 @@ test_that("AppenderFileRotatingDate: works as expected", {
   if (!is_zipcmd_available())
     skip("Test requires a workings system zip command")
 
-  assert_supported_rotor_version()
+  skip_if_not_installed("rotor", "0.3.0")
 
   tf <- file.path(td, "test.log")
   app <- AppenderFileRotatingDate$new(file = tf, size = "1tb")
@@ -226,10 +220,8 @@ test_that("AppenderFileRotatingDate: works as expected", {
 
 
 test_that("AppenderFileRotatingDate: works with different backup_dir", {
-  if (!is_zipcmd_available())
-    skip("Test requires a workings system zip command")
-
-  assert_supported_rotor_version()
+  skip_if_not(is_zipcmd_available(), "Test requires a workings system zip command")
+  skip_if_not_installed("rotor", "0.3.0")
 
   tf     <- file.path(td, "test.log")
   bu_dir <- file.path(td, "backups")
@@ -273,7 +265,7 @@ test_that("AppenderFileRotatingDate: works with different backup_dir", {
 
 
 test_that("AppenderFileRotatingDate: `size` and `age` arguments work as expected", {
-  assert_supported_rotor_version()
+  skip_if_not_installed("rotor", "0.3.0")
 
   #setup
   tf <- file.path(td, "test.log")
@@ -309,10 +301,8 @@ test_that("AppenderFileRotatingDate: `size` and `age` arguments work as expected
 # AppenderFileRotatingTime ----------------------------------------------------
 
 test_that("AppenderFileRotatingTime: works as expected", {
-  if (!is_zipcmd_available())
-    skip("Test requires a workings system zip command")
-
-  assert_supported_rotor_version()
+  skip_if_not(is_zipcmd_available(), "Test requires a workings system zip command")
+  skip_if_not_installed("rotor", "0.3.0")
 
   tf <- file.path(td, "test.log")
   app <- AppenderFileRotatingTime$new(file = tf)
@@ -357,10 +347,8 @@ test_that("AppenderFileRotatingTime: works as expected", {
 
 
 test_that("AppenderFileRotatingTime: works with different backup_dir", {
-  if (!is_zipcmd_available())
-    skip("Test requires a workings system zip command")
-
-  assert_supported_rotor_version()
+  skip_if_not(is_zipcmd_available(), "Test requires a workings system zip command")
+  skip_if_not_installed("rotor", "0.3.0")
 
   tf     <- file.path(td, "test.log")
   bu_dir <- file.path(td, "backups")
@@ -407,6 +395,8 @@ test_that("AppenderFileRotatingTime: works with different backup_dir", {
 
 test_that("AppenderFileRotatingTime: `size` and `age` arguments work as expected", {
 
+  skip_if_not_installed("rotor", "0.3.0")
+
   #setup
   tf <- file.path(td, "test.log")
   app <- AppenderFileRotatingTime$new(file = tf)$set_age(-1)
@@ -421,7 +411,7 @@ test_that("AppenderFileRotatingTime: `size` and `age` arguments work as expected
   app$rotate()
   expect_identical(nrow(app$backups), 0L)
 
-  app$set_size(file.size(tf) / 2)
+  app$set_size(floor(file.size(tf) / 2))
   app$rotate(now = "2999-01-01")
   expect_identical(nrow(app$backups), 1L)
 
@@ -439,6 +429,7 @@ test_that("AppenderFileRotatingTime: `size` and `age` arguments work as expected
 # Issues ------------------------------------------------------------------
 
 test_that("AppenderFileRotatingTime: `size` and `age` arguments work as expected #39", {
+  skip_if_not_installed("rotor", "0.3.0")
 
   #setup
   tf <- file.path(td, "test.log")
