@@ -6,7 +6,10 @@ tevent <- LogEvent$new(
   level = 200L,
   timestamp = as.POSIXct(1541175573.9308, origin = "1970-01-01", tz = "UTC"),
   caller = NA_character_,
-  msg = "foo bar"
+  msg = "foo bar",
+  rawMsg = "foo raw",
+  customField = "hashbaz",
+  customField2 = "barfoo"
 )
 
 
@@ -30,6 +33,26 @@ test_that("LayoutFormat works as expected", {
 })
 
 
+test_that("LayoutFormat works as expected with custom fields", {
+  lo <- LayoutFormat$new("%r %j")
+  expect_identical(lo$format_event(tevent), "foo raw {\"customField\":\"hashbaz\",\"customField2\":\"barfoo\"}")
+
+  lo$set_timestamp_fmt("%Y-%m-%d")
+  lo$set_fmt("[%t]")
+  expect_identical(lo$format_event(tevent), "[2018-11-02]")
+})
+
+
+test_that("LayoutFormat works as expected with custom fields", {
+  lo <- LayoutFormat$new("%r %j", excluded_fields = "customField2")
+  expect_identical(lo$format_event(tevent), "foo raw {\"customField\":\"hashbaz\"}")
+
+  lo$set_timestamp_fmt("%Y-%m-%d")
+  lo$set_fmt("[%t]")
+  expect_identical(lo$format_event(tevent), "[2018-11-02]")
+})
+
+
 
 test_that("LayoutGlue works as expected", {
   # basic formatting works
@@ -52,44 +75,3 @@ test_that("LayoutGlue works as expected", {
     expect_true(crayon::has_style(lo$format_event(tevent)))
   }
 })
-
-
-
-# LayoutJson --------------------------------------------------------------
-
-test_that("LayoutJson works as expected", {
-  lo <- LayoutJson$new()
-
-  x <- tevent$clone()
-  x$foo <- "bar"
-
-  eres <- x$values
-  json <- lo$format_event(x)
-  tres <- jsonlite::fromJSON(json)
-
-  tres[sapply(tres, is.null)] <- NA_character_
-  expect_setequal(c(names(eres), "foo"), names(tres))
-  expect_identical(tres[["level"]], eres[["level"]])
-  expect_identical(tres[["msg"]], eres[["msg"]])
-  expect_identical(tres[["caller"]], eres[["caller"]])
-  expect_equal(as.POSIXct(tres[["timestamp"]], tz = "UTC"), eres[["timestamp"]], tolerance = 1)
-  expect_equal(tres[["foo"]], "bar")
-})
-
-
-
-
-test_that("formatting timestamps with LayoutJson works", {
-  lo <- LayoutJson$new()
-  x <- tevent$clone()
-
-  eres <- x$values
-  json <- lo$format_event(x)
-
-  lo$set_timestamp_fmt(function(x) "fmt timestamp with function")
-  expect_match(lo$format_event(x), "fmt timestamp with function")
-
-  lo$set_timestamp_fmt("%H:%M:%S..%OS")
-  expect_match(lo$format_event(x), format(x$timestamp, "%H:%M:%S..%OS"))
-})
-
