@@ -1,6 +1,9 @@
 context("Logger")
 
 
+# Logger ------------------------------------------------------------------
+
+
 
 test_that("logging conditions works", {
   e <- error("blahblah")
@@ -318,6 +321,24 @@ test_that("$ancestry works", {
 })
 
 
+test_that("Logger handles null values", {
+  l <- Logger$new("test", propagate = FALSE)
+
+  log_null <- l$info("foo %s %s", NULL, character())
+  expect_equal(log_null, "foo <NULL> <NULL>")
+})
+
+
+test_that("Logger handles null values along with named parameters", {
+  l <- Logger$new("test", propagate = FALSE)
+
+  log_null <- l$info("foo %s %s", NULL, character(), valbert = "hashbaz", nullbert = NULL)
+  expect_equal(log_null, "foo <NULL> <NULL>")
+
+  expect_true(l$last_event$valbert == "hashbaz")
+  expect_true("nullbert" %in% names(l$last_event$values))
+  expect_null(l$last_event$nullbert)
+})
 
 
 # LoggerGlue --------------------------------------------------------------
@@ -344,8 +365,6 @@ test_that("LoggerGlue supports custom fields", {
 })
 
 
-
-
 test_that("LoggerGlue uses the correct evaluation environment", {
   l <- LoggerGlue$new("glue", propagate = FALSE)
 
@@ -356,8 +375,6 @@ test_that("LoggerGlue uses the correct evaluation environment", {
 })
 
 
-
-
 test_that("$config works with lists", {
   l <- LoggerGlue$new("glue", propagate = FALSE)
 
@@ -377,13 +394,53 @@ test_that("$config works with lists", {
 })
 
 
+test_that("LoggerGlue handles null values", {
+  l <- LoggerGlue$new("glue", propagate = FALSE)
+
+  log_null <- l$info("foo", NULL)
+  expect_equal(log_null, "foo<NULL>")
+
+  log_null_parameter <- l$info("foo {bar} {baz}", bar = NULL, baz = character())
+  expect_equal(log_null_parameter, "foo <NULL> <NULL>")
+})
 
 
+test_that("LoggerGlue handles null values along with named parameters", {
+  l <- LoggerGlue$new("test", propagate = FALSE)
+
+  log_null <- l$info("foo ", NULL, character(), valbert = "hashbaz", nullbert = NULL)
+  expect_equal(log_null, "foo <NULL><NULL>")
+
+  expect_true(l$last_event$valbert == "hashbaz")
+  expect_true("nullbert" %in% names(l$last_event$values))
+  expect_null(l$last_event$nullbert)
+})
+
+
+test_that("Logger glue can use custom transformers", {
+  transformer <- function(text, envir) {
+    "transformed text"
+  }
+
+  l <- LoggerGlue$new("glue", propagate = FALSE, transformer = transformer)
+
+  e <- log_null <- l$info("foo {bar}", foo = "bar")
+
+  expect_equal(e, "foo transformed text")
+})
+
+
+# Multi-Logger tests -------------------------------------------------------------
 
 test_that("Logger$log() dispatches to all appenders, even if some throw an error", {
   ln <- Logger$new("normal", propagate = FALSE)
   lg <- LoggerGlue$new("glue", propagate = FALSE)
 
+  on.exit({
+    ln$config(NULL)
+    lg$config(NULL)
+  })
+
   AppErr <- R6::R6Class(
     inherit = AppenderConsole,
     public = list(
@@ -416,6 +473,11 @@ test_that("Logger error contains useful call object", {
   l <- get_logger("test")
   g <- get_logger_glue("testglue")
 
+  on.exit({
+    l$config(NULL)
+    g$config(NULL)
+  })
+
   expect_warning(l$info("this will fail", e = stop()), "l\\$info")
   expect_warning(g$info("this will fail", e = stop()), "g\\$info")
 })
@@ -428,6 +490,11 @@ test_that("Appender error contains useful call object", {
   l <- get_logger("test")$set_propagate(FALSE)
   g <- get_logger_glue("testglue")$set_propagate(FALSE)
 
+  on.exit({
+    l$config(NULL)
+    g$config(NULL)
+  })
+
   AppenderFail <- R6::R6Class(
     "AppenderFail",
     inherit = Appender,
@@ -445,3 +512,53 @@ test_that("Appender error contains useful call object", {
   expect_warning(g$info("this will fail"), ".*AppenderFail.*g\\$info")
 })
 
+
+test_that("Logger$log - with 'msg' argument - logs the message", {
+  l <- get_logger("test")$set_propagate(FALSE)
+
+  on.exit({
+    l$config(NULL)
+  })
+
+  expect_silent(l$log(level = "fatal", msg = "test"))
+})
+
+
+test_that("LoggerGlue$log - with 'msg' argument - throws a warning", {
+  l <- get_logger_glue("testglue")$set_propagate(FALSE)
+
+  on.exit({
+    l$config(NULL)
+  })
+
+  expect_warning(l$log(level = "fatal", msg = "test"), "does not support")
+})
+
+
+test_that("Logger$log - with string interpolation - adds rawMsg to event", {
+  l <- get_logger("test")$set_propagate(FALSE)
+
+  on.exit({
+    l$config(NULL)
+  })
+
+  l$info("foo %s", "bar")
+
+  expect_identical(l$last_event$msg, "foo bar")
+  expect_identical(l$last_event$rawMsg, "foo %s")
+})
+
+
+test_that("LoggerGlue$log - with string interpolation - adds rawMsg to event", {
+  l <- get_logger_glue("testglue")$set_propagate(FALSE)
+
+  on.exit({
+    l$config(NULL)
+  })
+
+  l$fatal("hash {x}", x = "baz")
+
+  expect_identical(as.character(l$last_event$msg), "hash baz")
+  expect_identical(l$last_event$rawMsg, "hash {x}")
+})
+
